import {Component} from '@angular/core';
import {IonicPage, LoadingController, ModalController, NavController, NavParams} from 'ionic-angular';
import {HomeService} from "../../home.service";
import {InfoDetailPage} from "../info-detail/info-detail";
import {LoginService} from "../../../login/login.service";
import {SearchFilterComponent} from "../../../../components/search-filter/search-filter";
import {DealService} from "../../../deal/deal.service";

@Component({
    selector: 'page-info-list',
    templateUrl: 'info-list.html',
})


export class InfoListPage {

    option = {
        type: '1',
        viewType: '1',  //增加用户体验的
        list: [  //默认事业单位
            {name: "事业单位", type: '1'},
            {name: "机关群团", type: '2'},
            {name: "行政执法", type: '0'},
        ],
        history: []
    };
    info = {
        list: [],
        page: 1,
        limit: 20,
        search: '',
        totalCount: null,
        type: 3,
        typeDataArr: [],
        typeFilter: [{lable: '宗旨业务', id: 1},
            {lable: '举办单位', id: 2},
            {lable: '事业单位', id: 3},
            {lable: '统一社会信用代码', id: 4}],
        // 过滤
        area: '',
        industry: '',
        funding: '',
        cause: '',
    };

    arr = new Array(10)

    constructor(public navCtrl: NavController, public navParams: NavParams,
                private loadCtrl: LoadingController, private homeSer: HomeService,
                private modalCtrl: ModalController,) {
    }

    ionViewDidLoad() {
        // this.getList();
        this.option.history = JSON.parse(localStorage.getItem('history'))
        this.info.typeDataArr = this.info.typeFilter
    }

    changeType() {
        // 过滤类型--关联--单位选择
        this.info.typeDataArr = this.option.type === '0' ? this.info.typeDataArr.filter(x => x.id !== 1) : this.info.typeFilter
        this.info.area = '';
        this.info.industry = '';
        this.info.funding = '';
        this.info.cause = '';
        this.info.list = [];
        this.info.search = '';
        this.option.history = JSON.parse(localStorage.getItem('history'))
    }

    // 搜索按钮
    getList(event?: any) {
        if (!this.info.search) return this.changeType()

        let list = JSON.parse(localStorage.getItem('history'))
        if (list) {
            if (list.length>9) list.pop()
            list.unshift(this.info.search)
            this.option.history = list
            localStorage.setItem('history', JSON.stringify(list))
        } else {
            let arr = new Array()
            arr.unshift(this.info.search)
            localStorage.setItem('history',JSON.stringify(arr));
        }
        this.option.type === '1' ? this.getUnit(event) : this.getCreditor(event);
    }

    //机关群团
    getCreditor(event?: any) {
        const loadCtrl = this.loadCtrl.create();
        loadCtrl.present();
        this.info.page = 1;
        const data = {
            search: this.info.search,
            page: this.info.page,
            limit: this.info.limit,
            type: '2',
            "areacode": "",
            "openid": ""
        };
        this.homeSer.creditorgan(data).subscribe(
            (res) => {
                loadCtrl.dismiss();
                if (event) event.complete();
                this.option.viewType = '2';
                this.info.list = res.page.list.object;
                this.info.totalCount = res.page.totalCount;
            }
        )
    }

    //事业单位
    getUnit(event?: any) {
        const loadCtrl = this.loadCtrl.create();
        loadCtrl.present();
        this.info.page = 1;
        const data = {
            search: this.info.search,
            page: this.info.page,
            limit: this.info.limit,
            type: '1',
            areacode: this.info.area,
            openid: "",
            isUnit: this.option.list.filter(x => x.type === this.option.type).map(x => x.type).toString(),
            hyfl: this.info.industry,
            jfxs: this.info.funding,
            dwfl: this.info.cause,
            searchType: this.info.type
        };
        this.homeSer.unitfind(data).subscribe(
            (res) => {
                loadCtrl.dismiss();
                if (event) event.complete();
                this.option.viewType = '1';
                this.info.list = res.page.list.object;
                this.info.totalCount = res.page.totalCount;
            }
        )
    }

    //加载更多
    doInfinite(event) {
        this.option.type === '1' ? this.getMoreUnit(event) : this.getMoreCreditor(event);
    }

    getMoreUnit(event) {
        if (this.info.totalCount == this.info.list.length) {
            event.enable(false);
            return false;
        }
        this.info.page++;
        const data = {
            search: this.info.search,
            page: this.info.page,
            limit: this.info.limit,
            type: '1',
            "areacode": "",
            "openid": ""
        };
        this.homeSer.unitfind(data).subscribe(
            (res) => {
                if (event) event.complete();
                this.info.list = this.info.list.concat(res.page.list.object);
                this.info.totalCount = res.page.totalCount;
            }
        )
    }

    getMoreCreditor(event) {
        if (this.info.totalCount == this.info.list.length) {
            event.enable(false);
            return false;
        }
        this.info.page++;
        const data = {
            search: this.info.search,
            page: this.info.page,
            limit: this.info.limit,
            type: '2',
            "areacode": "",
            "openid": ""
        };
        this.homeSer.creditorgan(data).subscribe(
            (res) => {
                if (event) event.complete();
                this.info.list = this.info.list.concat(res.page.list.object);
                this.info.totalCount = res.page.totalCount;
            }
        )
    }

    //查询详情
    goToDetail(item) {
        this.navCtrl.push(InfoDetailPage, {obj: item, type: this.option.type});
    }

    // 选择类型
    switchType(){
        console.log(this.info.type)
    }

    // 选择类型
    filterConditions() {
        let modal = this.modalCtrl.create(SearchFilterComponent, {
                groupType: this.option.list.filter(x => x.type === this.option.type).map(x => x.name),
                type: this.info.typeDataArr.filter(x => x.id === this.info.type).map(x => x.lable),
            },
            {
                enterAnimation: 'modal-from-right-enter',
                leaveAnimation: 'modal-from-right-leave'
            });
        modal.onDidDismiss(res => {
            if (res) {
                this.info.area = res.area.code
                this.info.industry = res.industry.code
                this.info.funding = res.funding.code
                this.info.cause = res.cause.code
            }
        });
        modal.present();
    }

    // 添加历史记录
    historyField(value){
        this.info.search = value
        this.getList()
    }

}
